==> jc-1.4.0.tar.gz: java/awt/font/GlyphJustificationInfo.h <==
// public final class java.awt.font.GlyphJustificationInfo

// class file dependencies
// @dep_class 3e4be06a7eb9a067 java_awt_font_GlyphJustificationInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_GlyphJustificationInfo_H_
#define _JC_java_awt_font_GlyphJustificationInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_GlyphJustificationInfo$sub_refs	_jc_java_awt_font_GlyphJustificationInfo$sub_refs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs	_jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$refs	_jc_java_awt_font_GlyphJustificationInfo$refs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$nonrefs	_jc_java_awt_font_GlyphJustificationInfo$nonrefs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$object	_jc_java_awt_font_GlyphJustificationInfo$object;

typedef struct _jc_java_awt_font_GlyphJustificationInfo$fields_struct	_jc_java_awt_font_GlyphJustificationInfo$fields_struct;
typedef const struct _jc_java_awt_font_GlyphJustificationInfo$vmethods	_jc_java_awt_font_GlyphJustificationInfo$vmethods;
typedef const struct _jc_java_awt_font_GlyphJustificationInfo$vtable	_jc_java_awt_font_GlyphJustificationInfo$vtable;
typedef const struct _jc_java_awt_font_GlyphJustificationInfo$vtype	_jc_java_awt_font_GlyphJustificationInfo$vtype;

// Class fields structure
struct _jc_java_awt_font_GlyphJustificationInfo$fields_struct {
	jint	PRIORITY__5fINTERCHAR;
	jint	PRIORITY__5fKASHIDA;
	jint	PRIORITY__5fNONE;
	jint	PRIORITY__5fWHITESPACE;
};
extern _jc_java_awt_font_GlyphJustificationInfo$fields_struct _jc_java_awt_font_GlyphJustificationInfo$class_fields;

// Constructors
extern void _jc_java_awt_font_GlyphJustificationInfo$method$_init$ab628a002e43b19f(_jc_env *, struct _jc_java_awt_font_GlyphJustificationInfo$object *, jfloat, jboolean, jint, jfloat, jfloat, jboolean, jint, jfloat, jfloat);

// Virtual methods structure
struct _jc_java_awt_font_GlyphJustificationInfo$vmethods {
};

// Vtable
struct _jc_java_awt_font_GlyphJustificationInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_GlyphJustificationInfo$vmethods	java_awt_font_GlyphJustificationInfo;
};

// Vtype
struct _jc_java_awt_font_GlyphJustificationInfo$vtype {
	_jc_type			type;
	_jc_java_awt_font_GlyphJustificationInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_GlyphJustificationInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_GlyphJustificationInfo$refs {
    _jc_java_awt_font_GlyphJustificationInfo$sub_refs	java_awt_font_GlyphJustificationInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs {
	jfloat	weight;
	jint	growPriority;
	jboolean	growAbsorb;
	jfloat	growLeftLimit;
	jfloat	growRightLimit;
	jint	shrinkPriority;
	jboolean	shrinkAbsorb;
	jfloat	shrinkLeftLimit;
	jfloat	shrinkRightLimit;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_GlyphJustificationInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs	java_awt_font_GlyphJustificationInfo;
};

// Object instance structure
struct _jc_java_awt_font_GlyphJustificationInfo$object {
	_jc_java_awt_font_GlyphJustificationInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_GlyphJustificationInfo$vtype	*vtype;
	_jc_java_awt_font_GlyphJustificationInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_GlyphJustificationInfo$vtype _jc_java_awt_font_GlyphJustificationInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_GlyphJustificationInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_GlyphJustificationInfo$class_object;

#endif	/* _JC_java_awt_font_GlyphJustificationInfo_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/GlyphJustificationInfo.h <==
// public final class java.awt.font.GlyphJustificationInfo

// class file dependencies
// @dep_class 3e4be06a7eb9a067 java_awt_font_GlyphJustificationInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_GlyphJustificationInfo_H_
#define _JC_java_awt_font_GlyphJustificationInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_font_GlyphJustificationInfo$sub_refs	_jc_java_awt_font_GlyphJustificationInfo$sub_refs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs	_jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$refs	_jc_java_awt_font_GlyphJustificationInfo$refs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$nonrefs	_jc_java_awt_font_GlyphJustificationInfo$nonrefs;
typedef struct _jc_java_awt_font_GlyphJustificationInfo$object	_jc_java_awt_font_GlyphJustificationInfo$object;

typedef struct _jc_java_awt_font_GlyphJustificationInfo$fields_struct	_jc_java_awt_font_GlyphJustificationInfo$fields_struct;
typedef const struct _jc_java_awt_font_GlyphJustificationInfo$vmethods	_jc_java_awt_font_GlyphJustificationInfo$vmethods;
typedef const struct _jc_java_awt_font_GlyphJustificationInfo$vtable	_jc_java_awt_font_GlyphJustificationInfo$vtable;
typedef const struct _jc_java_awt_font_GlyphJustificationInfo$vtype	_jc_java_awt_font_GlyphJustificationInfo$vtype;

// Class fields structure
struct _jc_java_awt_font_GlyphJustificationInfo$fields_struct {
	jint	PRIORITY__5fINTERCHAR;
	jint	PRIORITY__5fKASHIDA;
	jint	PRIORITY__5fNONE;
	jint	PRIORITY__5fWHITESPACE;
};
extern _jc_java_awt_font_GlyphJustificationInfo$fields_struct _jc_java_awt_font_GlyphJustificationInfo$class_fields;

// Constructors
extern void _jc_java_awt_font_GlyphJustificationInfo$method$_init$ab628a002e43b19f(_jc_env *, struct _jc_java_awt_font_GlyphJustificationInfo$object *, jfloat, jboolean, jint, jfloat, jfloat, jboolean, jint, jfloat, jfloat) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_font_GlyphJustificationInfo$vmethods {
};

// Vtable
struct _jc_java_awt_font_GlyphJustificationInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_GlyphJustificationInfo$vmethods	java_awt_font_GlyphJustificationInfo;
};

// Vtype
struct _jc_java_awt_font_GlyphJustificationInfo$vtype {
	_jc_type			type;
	_jc_java_awt_font_GlyphJustificationInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_GlyphJustificationInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_font_GlyphJustificationInfo$refs {
    _jc_java_awt_font_GlyphJustificationInfo$sub_refs	java_awt_font_GlyphJustificationInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs {
	jfloat	weight;
	jint	growPriority;
	jboolean	growAbsorb;
	jfloat	growLeftLimit;
	jfloat	growRightLimit;
	jint	shrinkPriority;
	jboolean	shrinkAbsorb;
	jfloat	shrinkLeftLimit;
	jfloat	shrinkRightLimit;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_GlyphJustificationInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_GlyphJustificationInfo$sub_nonrefs	java_awt_font_GlyphJustificationInfo;
};

// Object instance structure
struct _jc_java_awt_font_GlyphJustificationInfo$object {
	_jc_java_awt_font_GlyphJustificationInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_GlyphJustificationInfo$vtype	*vtype;
	_jc_java_awt_font_GlyphJustificationInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_GlyphJustificationInfo$vtype _jc_java_awt_font_GlyphJustificationInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_GlyphJustificationInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_GlyphJustificationInfo$class_object;

#endif	/* _JC_java_awt_font_GlyphJustificationInfo_H_ */
